==> core-1.8.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/core/CfnAutoScalingScheduledAction.java <==
package software.amazon.awscdk.core;

/**
 * With scheduled actions, the group size properties of an Auto Scaling group can change at any time.
 * 
 * When you update a
 * stack with an Auto Scaling group and scheduled action, AWS CloudFormation always sets the group size property values of
 * your Auto Scaling group to the values that are defined in the AWS::AutoScaling::AutoScalingGroup resource of your template,
 * even if a scheduled action is in effect.
 * 
 * If you do not want AWS CloudFormation to change any of the group size property values when you have a scheduled action in
 * effect, use the AutoScalingScheduledAction update policy to prevent AWS CloudFormation from changing the MinSize, MaxSize,
 * or DesiredCapacity properties unless you have modified these values in your template.\
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.16.0 (build 98909b5)", date = "2019-09-10T21:04:46.892Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnAutoScalingScheduledAction extends software.amazon.jsii.JsiiSerializable {
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.Boolean getIgnoreUnmodifiedGroupSizeProperties();

    /**
     * @return a {@link Builder} of {@link CfnAutoScalingScheduledAction}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnAutoScalingScheduledAction}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Builder {
        private java.lang.Boolean ignoreUnmodifiedGroupSizeProperties;

        /**
         * Sets the value of IgnoreUnmodifiedGroupSizeProperties
         * @param ignoreUnmodifiedGroupSizeProperties the value to be set
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ignoreUnmodifiedGroupSizeProperties(java.lang.Boolean ignoreUnmodifiedGroupSizeProperties) {
            this.ignoreUnmodifiedGroupSizeProperties = ignoreUnmodifiedGroupSizeProperties;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnAutoScalingScheduledAction}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public CfnAutoScalingScheduledAction build() {
            return new Jsii$Proxy(ignoreUnmodifiedGroupSizeProperties);
        }

    }

    /**
     * An implementation for {@link CfnAutoScalingScheduledAction}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnAutoScalingScheduledAction {
        private final java.lang.Boolean ignoreUnmodifiedGroupSizeProperties;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.ignoreUnmodifiedGroupSizeProperties = this.jsiiGet("ignoreUnmodifiedGroupSizeProperties", java.lang.Boolean.class);
        }


        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.Boolean ignoreUnmodifiedGroupSizeProperties) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.ignoreUnmodifiedGroupSizeProperties = ignoreUnmodifiedGroupSizeProperties;
        }

        @Override
        public java.lang.Boolean getIgnoreUnmodifiedGroupSizeProperties() {
            return this.ignoreUnmodifiedGroupSizeProperties;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            if (this.getIgnoreUnmodifiedGroupSizeProperties() != null) {
                obj.set("ignoreUnmodifiedGroupSizeProperties", om.valueToTree(this.getIgnoreUnmodifiedGroupSizeProperties()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnAutoScalingScheduledAction.Jsii$Proxy that = (CfnAutoScalingScheduledAction.Jsii$Proxy) o;

            return this.ignoreUnmodifiedGroupSizeProperties != null ? this.ignoreUnmodifiedGroupSizeProperties.equals(that.ignoreUnmodifiedGroupSizeProperties) : that.ignoreUnmodifiedGroupSizeProperties == null;
        }

        @Override
        public int hashCode() {
            int result = this.ignoreUnmodifiedGroupSizeProperties != null ? this.ignoreUnmodifiedGroupSizeProperties.hashCode() : 0;
            return result;
        }

    }
}

==> core-1.9.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/core/CfnAutoScalingScheduledAction.java <==
package software.amazon.awscdk.core;

/**
 * With scheduled actions, the group size properties of an Auto Scaling group can change at any time.
 * 
 * When you update a
 * stack with an Auto Scaling group and scheduled action, AWS CloudFormation always sets the group size property values of
 * your Auto Scaling group to the values that are defined in the AWS::AutoScaling::AutoScalingGroup resource of your template,
 * even if a scheduled action is in effect.
 * 
 * If you do not want AWS CloudFormation to change any of the group size property values when you have a scheduled action in
 * effect, use the AutoScalingScheduledAction update policy to prevent AWS CloudFormation from changing the MinSize, MaxSize,
 * or DesiredCapacity properties unless you have modified these values in your template.\
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.0 (build 7d5d104)", date = "2019-09-20T09:44:35.441Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnAutoScalingScheduledAction extends software.amazon.jsii.JsiiSerializable {

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.Boolean getIgnoreUnmodifiedGroupSizeProperties();

    /**
     * @return a {@link Builder} of {@link CfnAutoScalingScheduledAction}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnAutoScalingScheduledAction}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private java.lang.Boolean ignoreUnmodifiedGroupSizeProperties;

        /**
         * Sets the value of IgnoreUnmodifiedGroupSizeProperties
         * @param ignoreUnmodifiedGroupSizeProperties the value to be set.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ignoreUnmodifiedGroupSizeProperties(java.lang.Boolean ignoreUnmodifiedGroupSizeProperties) {
            this.ignoreUnmodifiedGroupSizeProperties = ignoreUnmodifiedGroupSizeProperties;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnAutoScalingScheduledAction}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public CfnAutoScalingScheduledAction build() {
            return new Jsii$Proxy(ignoreUnmodifiedGroupSizeProperties);
        }
    }

    /**
     * An implementation for {@link CfnAutoScalingScheduledAction}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnAutoScalingScheduledAction {
        private final java.lang.Boolean ignoreUnmodifiedGroupSizeProperties;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.ignoreUnmodifiedGroupSizeProperties = this.jsiiGet("ignoreUnmodifiedGroupSizeProperties", java.lang.Boolean.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.Boolean ignoreUnmodifiedGroupSizeProperties) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.ignoreUnmodifiedGroupSizeProperties = ignoreUnmodifiedGroupSizeProperties;
        }

        @Override
        public java.lang.Boolean getIgnoreUnmodifiedGroupSizeProperties() {
            return this.ignoreUnmodifiedGroupSizeProperties;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            if (this.getIgnoreUnmodifiedGroupSizeProperties() != null) {
                obj.set("ignoreUnmodifiedGroupSizeProperties", om.valueToTree(this.getIgnoreUnmodifiedGroupSizeProperties()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnAutoScalingScheduledAction.Jsii$Proxy that = (CfnAutoScalingScheduledAction.Jsii$Proxy) o;

            return this.ignoreUnmodifiedGroupSizeProperties != null ? this.ignoreUnmodifiedGroupSizeProperties.equals(that.ignoreUnmodifiedGroupSizeProperties) : that.ignoreUnmodifiedGroupSizeProperties == null;
        }

        @Override
        public int hashCode() {
            int result = this.ignoreUnmodifiedGroupSizeProperties != null ? this.ignoreUnmodifiedGroupSizeProperties.hashCode() : 0;
            return result;
        }
    }
}
